@@ -1,3 +1,9 @@
+# Copyright (c) 2013, Avraham Adler All rights reserved
+# SPDX-License-Identifier: BSD-2-Clause
+
+# For CRAN
+setDelapThreads(2L)
+
 tol <- 1e-12
 nanWarn <- "NaNs produced"
 inpErr <- "Quantile approximation relies on pooling"
