@@ -27,10 +27,28 @@
 //  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 //  POSSIBILITY OF SUCH DAMAGE.
 
-void F77_NAME(ddelap_f)(double *x, int nx, double *a, int na, double *b, 
-              int nb, double *l, int nl, int *lg, double *ret);
+void F77_NAME(gOMPT_f)(int *ret);
 
-extern SEXP ddelap_C(SEXP x, SEXP alpha, SEXP beta, SEXP lambda, SEXP lg){
+extern SEXP gOMPT_C(void){
+  SEXP ret;
+  PROTECT(ret = allocVector(INTSXP, 1));
+  F77_CALL(gOMPT_f)(INTEGER(ret));
+  UNPROTECT(1);
+  return(ret);
+}
+
+void F77_NAME(sOMPT_f)(int *n);
+
+extern SEXP sOMPT_C(SEXP n){
+  F77_CALL(sOMPT_f)(INTEGER(n));
+  return(n);
+}
+
+void F77_NAME(ddelap_f)(double *x, int nx, double *a, int na, double *b, 
+              int nb, double *l, int nl, int *lg, int *threads, double *ret);
+
+extern SEXP ddelap_C(SEXP x, SEXP alpha, SEXP beta, SEXP lambda, SEXP lg,
+                     SEXP threads){
   const int nx = LENGTH(x);
   const int na = LENGTH(alpha);
   const int nb = LENGTH(beta);
@@ -38,16 +56,16 @@ extern SEXP ddelap_C(SEXP x, SEXP alpha, SEXP beta, SEXP lambda, SEXP lg){
   SEXP ret;
   PROTECT(ret = allocVector(REALSXP, nx));
   F77_CALL(ddelap_f)(REAL(x), nx, REAL(alpha), na, REAL(beta), nb, REAL(lambda),
-           nl, INTEGER(lg), REAL(ret));
+           nl, INTEGER(lg), INTEGER(threads), REAL(ret));
   UNPROTECT(1);
   return(ret);
 }
 
 void F77_NAME(pdelap_f)(double *q, int nq, double *a, int na, double *b, int nb,
-              double *l, int nl, int *lt, int *lg, double *ret);
+              double *l, int nl, int *lt, int *lg, int *threads, double *ret);
 
 extern SEXP pdelap_C(SEXP q, SEXP alpha, SEXP beta, SEXP lambda, SEXP lt,
-                     SEXP lg){
+                     SEXP lg, SEXP threads){
   const int nq = LENGTH(q);
   const int na = LENGTH(alpha);
   const int nb = LENGTH(beta);
@@ -55,16 +73,16 @@ extern SEXP pdelap_C(SEXP q, SEXP alpha, SEXP beta, SEXP lambda, SEXP lt,
   SEXP ret;
   PROTECT(ret = allocVector(REALSXP, nq));
   F77_CALL(pdelap_f)(REAL(q), nq, REAL(alpha), na, REAL(beta), nb, REAL(lambda),
-           nl, INTEGER(lt), INTEGER(lg), REAL(ret));
+           nl, INTEGER(lt), INTEGER(lg), INTEGER(threads), REAL(ret));
   UNPROTECT(1);
   return(ret);
 }
 
 void F77_NAME(qdelap_f)(double *p, int np, double *a, int na, double *b, int nb,
-              double *l, int nl, int *lt, int *lg, double *ret);
+              double *l, int nl, int *lt, int *lg, int *threads, double *ret);
 
 extern SEXP qdelap_C(SEXP p, SEXP alpha, SEXP beta, SEXP lambda, SEXP lt,
-                     SEXP lg){
+                     SEXP lg, SEXP threads){
   const int np = LENGTH(p);
   const int na = LENGTH(alpha);
   const int nb = LENGTH(beta);
@@ -72,15 +90,15 @@ extern SEXP qdelap_C(SEXP p, SEXP alpha, SEXP beta, SEXP lambda, SEXP lt,
   SEXP ret;
   PROTECT(ret = allocVector(REALSXP, np));
   F77_CALL(qdelap_f)(REAL(p), np, REAL(alpha), na, REAL(beta), nb, REAL(lambda),
-           nl, INTEGER(lt), INTEGER(lg), REAL(ret));
+           nl, INTEGER(lt), INTEGER(lg), INTEGER(threads), REAL(ret));
   UNPROTECT(1);
   return(ret);
 }
 
 void F77_NAME(rdelap_f)(int n, double *a, int na, double *b, int nb, double *l,
-              int nl, double *ret);
+              int nl, int *threads, double *ret);
 
-extern SEXP rdelap_C(SEXP n, SEXP alpha, SEXP beta, SEXP lambda){
+extern SEXP rdelap_C(SEXP n, SEXP alpha, SEXP beta, SEXP lambda, SEXP threads){
   const int nn = INTEGER(n)[0];
   const int na = LENGTH(alpha);
   const int nb = LENGTH(beta);
@@ -88,7 +106,7 @@ extern SEXP rdelap_C(SEXP n, SEXP alpha, SEXP beta, SEXP lambda){
   SEXP ret;
   PROTECT(ret = allocVector(REALSXP, nn));
   F77_CALL(rdelap_f)(nn, REAL(alpha), na, REAL(beta), nb, REAL(lambda), nl,
-           REAL(ret));
+           INTEGER(threads), REAL(ret));
   UNPROTECT(1);
   return(ret);
 }
@@ -113,11 +131,13 @@ void F77_SUB(unifrnd) (int *n, double *x){
 }
 
 static const R_CallMethodDef CallEntries[] = {
-    {"ddelap_C",    (DL_FUNC) &ddelap_C,   5},
-    {"pdelap_C",    (DL_FUNC) &pdelap_C,   6},
-    {"qdelap_C",    (DL_FUNC) &qdelap_C,   6},
-    {"rdelap_C",    (DL_FUNC) &rdelap_C,   4},
+    {"ddelap_C",    (DL_FUNC) &ddelap_C,   6},
+    {"pdelap_C",    (DL_FUNC) &pdelap_C,   7},
+    {"qdelap_C",    (DL_FUNC) &qdelap_C,   7},
+    {"rdelap_C",    (DL_FUNC) &rdelap_C,   5},
     {"MoMdelap_C",  (DL_FUNC) &MoMdelap_C, 2},
+    {"gOMPT_C",     (DL_FUNC) &gOMPT_C,    0},
+    {"sOMPT_C",     (DL_FUNC) &sOMPT_C,    1},
     {NULL,                    NULL,        0}
 };
 
@@ -130,4 +150,6 @@ void R_init_Delaporte(DllInfo *dll) {
   R_RegisterCCallable("Delaporte", "qdelap_C",  (DL_FUNC) &qdelap_C);
   R_RegisterCCallable("Delaporte", "rdelap_C",  (DL_FUNC) &rdelap_C);
   R_RegisterCCallable("Delaporte", "MoMdelap_C",(DL_FUNC) &MoMdelap_C);
+  R_RegisterCCallable("Delaporte", "gOMPT_C",   (DL_FUNC) &gOMPT_C);
+  R_RegisterCCallable("Delaporte", "sOMPT_C",   (DL_FUNC) &sOMPT_C);
 }
